Ipfs class

Constructors

Ipfs({String? host, bool noPort = false})

Properties

apiPath → String
final
apiPort → int
final
apiUrl → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
getter/setter pair
localhost → String
final
noPort ↔ bool
getter/setter pair
onLocal ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webPath → String
final
webPort → int
final
webUrl → String
no setter

Methods

add(MultipartFile f) → Future<String>
cat(dynamic url) → Future<ByteStream>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInit() → void
parseUrl(String urla) → String
post(String cmd, dynamic c, MultipartFile? f) → Future<Map<String, dynamic>>
put(dynamic d) → Future<ByteStream>
query(Request request) → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defHost ↔ String
getter/setter pair